@@ -25,7 +25,7 @@ di1_futures <- df |>
         maturity_date = maturity2date(maturity_code),
         fixing = following(maturity_date, "Brazil/ANBIMA"),
         business_days = bizdays(refdate, maturity_date, "Brazil/ANBIMA"),
-        adjusted_tax = rates("discrete", business_days / 252, 100000 / price)
+        adjusted_tax = implied_rate("discrete", business_days / 252, 100000 / price)
     ) |>
     filter(business_days > 0)
 
@@ -50,7 +50,7 @@ dap_futures <- df |>
         maturity_date = maturity2date(maturity_code, "15th day"),
         fixing = following(maturity_date, "Brazil/ANBIMA"),
         business_days = bizdays(refdate, maturity_date, "Brazil/ANBIMA"),
-        adjusted_tax = rates("discrete", business_days / 252, 100000 / price)
+        adjusted_tax = implied_rate("discrete", business_days / 252, 100000 / price)
     ) |>
     filter(business_days > 0)
 
@@ -78,7 +78,7 @@ infl_futures <- df |>
         ),
         fixing = following(maturity_date, "Brazil/ANBIMA"),
         business_days = bizdays(refdate, maturity_date, "Brazil/ANBIMA"),
-        adjusted_tax = rates("discrete", business_days / 252, 100000 / price)
+        adjusted_tax = implied_rate("discrete", business_days / 252, 100000 / price)
     ) |>
     arrange(refdate)
 
