@@ -1,5 +1,5 @@
 
-test_that("it should get futures data", {
+test_that("it should get futures data with futures_mget", {
   if (!covr::in_covr()) {
     skip_on_cran()
     skip_if_offline()
@@ -8,13 +8,36 @@ test_that("it should get futures data", {
   first_date <- Sys.Date() - 5
   last_date <- Sys.Date()
 
-  df_yc_1 <- futures_get(first_date, last_date, do_cache = FALSE)
+  df_yc_1 <- futures_mget(first_date, last_date, do_cache = FALSE)
 
   expect_true(nrow(df_yc_1) > 0)
   expect_true(ncol(df_yc_1) > 0)
   expect_true(tibble::is_tibble(df_yc_1))
 
-  df_yc_2 <- futures_get(first_date, last_date)
+  df_yc_2 <- futures_mget(first_date, last_date)
+
+  expect_true(nrow(df_yc_2) > 0)
+  expect_true(ncol(df_yc_2) > 0)
+  expect_true(tibble::is_tibble(df_yc_2))
+
+  expect_identical(df_yc_1, df_yc_2)
+})
+
+test_that("it should get futures data with futures_get", {
+  if (!covr::in_covr()) {
+    skip_on_cran()
+    skip_if_offline()
+  }
+
+  refdate <- bizdays::offset(Sys.Date(), -1, "Brazil/ANBIMA")
+
+  df_yc_1 <- futures_get(refdate, do_cache = FALSE)
+
+  expect_true(nrow(df_yc_1) > 0)
+  expect_true(ncol(df_yc_1) > 0)
+  expect_true(tibble::is_tibble(df_yc_1))
+
+  df_yc_2 <- futures_get(refdate)
 
   expect_true(nrow(df_yc_2) > 0)
   expect_true(ncol(df_yc_2) > 0)
